==> org.eclipse.papyrus.designer.components.transformation.ui.source_2.0.0.202105090719.jar: org/eclipse/papyrus/designer/components/transformation/ui/handlers/SyncHandler.java <==
/*****************************************************************************
 * Copyright (c) 2017 CEA LIST.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *  Ansgar Radermacher  ansgar.radermacher@cea.fr
 *
 *****************************************************************************/

package org.eclipse.papyrus.designer.components.transformation.ui.handlers;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.papyrus.designer.components.transformation.sync.CompImplSync;
import org.eclipse.papyrus.designer.transformation.base.utils.CommandSupport;
import org.eclipse.papyrus.uml.diagram.common.handlers.CmdHandler;
import org.eclipse.uml2.uml.Class;

/**
 * Handler for synchronizing derived elements. Specialization for components (update of ports)
 */
public class SyncHandler extends CmdHandler {

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean isEnabled() {
		updateSelectedEObject();
		return true;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		// if a property is selected, use the associated type
		if (selectedEObject instanceof Class) {
			final Class selectedClass = (Class) selectedEObject;
			CommandSupport.exec("Synchronize class (components)", event, new Runnable() { //$NON-NLS-1$

				@Override
				public void run() {
					CompImplSync.updatePorts(selectedClass);
					CompImplSync.syncRealizations(selectedClass);
				}
			});
		}
		return null;
	}
}

==> org.eclipse.papyrus.designer.components.transformation.ui.source_3.1.0.202407120007.jar: org/eclipse/papyrus/designer/components/transformation/ui/handlers/SyncHandler.java <==
/*****************************************************************************
 * Copyright (c) 2017 CEA LIST.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *  Ansgar Radermacher  ansgar.radermacher@cea.fr
 *
 *****************************************************************************/

package org.eclipse.papyrus.designer.components.transformation.ui.handlers;

import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.papyrus.designer.components.transformation.sync.CompImplSync;
import org.eclipse.papyrus.designer.infra.base.CommandSupport;
import org.eclipse.papyrus.uml.diagram.common.handlers.CmdHandler;
import org.eclipse.uml2.uml.Class;

/**
 * Handler for synchronizing derived elements. Specialization for components
 * (update of ports)
 */
public class SyncHandler extends CmdHandler {

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean isEnabled() {
		updateSelectedEObject();
		return true;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		// if a property is selected, use the associated type
		if (selectedEObject instanceof Class) {
			final Class selectedClass = (Class) selectedEObject;
			CommandSupport.exec(selectedClass, "Synchronize class (components)", new Runnable() { //$NON-NLS-1$

				@Override
				public void run() {
					CompImplSync.updatePorts(selectedClass);
					CompImplSync.syncRealizations(selectedClass);
				}
			});
		}
		return null;
	}
}
